@@ -1,11 +1,8 @@
-( cd usr/share/doc/gnome-utils-2.10.1 ; rm -rf build )
-( cd usr/share/doc/gnome-utils-2.10.1 ; ln -sf /usr/src/garnome-Ptgz-kit build )
 ( cd usr/bin ; rm -rf gnome-panel-screenshot )
 ( cd usr/bin ; ln -sf gnome-screenshot gnome-panel-screenshot )
-#%% begin initialize gnome_utils-2.10.1-i386-P1
-if [ -x /usr/bin/update-desktop-database ]; then
-  /usr/bin/update-desktop-database /usr/share/applications
-fi
+( cd usr/share/doc/gnome-utils-2.12.2 ; rm -rf build )
+( cd usr/share/doc/gnome-utils-2.12.2 ; ln -sf /usr/src/garnome-Ptgz-kit build )
+#%% begin initialize gnome_utils-2.12.2-i386-P1
 if [ -x /usr/bin/scrollkeeper-update ]; then
   /usr/bin/scrollkeeper-update -q || exit 1
 fi
@@ -19,7 +16,6 @@ GCONF_DIR=/usr/etc/gconf
 SCHEMA_DIR=$GCONF_DIR/schemas
 SCHEMA_FILES=" \
   gdict.schemas \
-  gfloppy.schemas \
   gnome-screenshot.schemas \
   gnome-search-tool.schemas \
   logview.schemas \
